#!/bin/bash

#log to services.log
exec 1> >(logger -s -p local6.info -t CleanCoreDumps) 2>&1

CORES_LIMIT=10
LOGS_REQUIRED_SPACE=524288

#$1 is the root forlder of executable, e.g. ./wanproxy/ or empty

# remove first dot in case of process in jail, asumming we are running in /opt/tcr
DIR=`basename $1 2>/dev/null`
RUNNING_SYSTEM="tcr"
if [ -d /opt/tma ]; then
    RUNNING_SYSTEM="tma"
fi

#read core files pattern from conf
CORE_FILE_PATTERN=`cat /proc/sys/kernel/core_pattern`
#extract dir
CORE_FILE_DIR=$(dirname "${CORE_FILE_PATTERN}")
#extract prefix
CORE_FILE_PREF=`basename "$CORE_FILE_PATTERN" | cut -d. -f1`
#read all types of executables (assuming first entry in pattern is executable name, e.g. wanproxy)
CORE_GET_EXEC=`ls $DIR$CORE_FILE_DIR/$CORE_FILE_PREF\.* 2> /dev/null | awk -F'[..]' '{print $2}' | uniq`
#limit the number of core dumps per wanproxy instance
if [[ $DIR == 'wanproxy' ]] && [ "$(echo $CORE_GET_EXEC | wc -w)" -gt "0" ]; then
    CORES_LIMIT=$(expr $CORES_LIMIT / $(echo $CORE_GET_EXEC | wc -w))
fi

#for every type of executable keep only the last 10
for f in $CORE_GET_EXEC;
do
  ls -t1 $DIR$CORE_FILE_DIR/$CORE_FILE_PREF\.$f* | tail -n +$(expr $CORES_LIMIT + 1) | xargs rm -r 2> /dev/null
done

AVAILABLE_DISC_SPACE=$(df /opt/$RUNNING_SYSTEM/ | awk 'FNR==2 { print $4 }')
while [ $AVAILABLE_DISC_SPACE -lt $LOGS_REQUIRED_SPACE ]
do
    # delete the oldest coredump
    SEARCH_PATH=$CORE_FILE_DIR 
    if [ "$RUNNING_SYSTEM" == "tcr" ] ; then
        # For TCR machines, search in wanproxy path as well.
        SEARCH_PATH="\"./wanproxy$CORE_FILE_DIR\" $CORE_FILE_DIR"
    fi
    oldest_core=$(find $SEARCH_PATH -type f -printf "%T+\t%p\n" | grep "$CORE_FILE_PREF\.*" | sort -r | awk '{ print $2 }' | tail -n 1)
    rm $oldest_core 2> /dev/null
    
    AVAILABLE_DISC_SPACE=$(df /opt/$RUNNING_SYSTEM/ | awk 'FNR==2 { print $4 }')
done

